@@ -31,3 +31,8 @@ create_pixmap = gdk.Pixmap
 create_pixmap_from_xpm = gdk.pixmap_create_from_xpm
 create_pixmap_from_xpm_d = gdk.pixmap_create_from_xpm_d
 
+threads_init = gdk.threads_init
+threads_enter = gdk.threads_leave
+threads_leave = gdk.threads_leave
+
+input_add = input_add_full
